@@ -59,7 +59,7 @@ class KScienceSaverInterface : public KScreenSaverInterface
 
 public:
     virtual KAboutData* aboutData() {
-        return new KAboutData( "kscience.kss", 0, ki18n( "Science Screen Saver" ), "2.2.0", ki18n( "Science Screen Saver" ) );
+        return new KAboutData( "kscience.kss", "klock", ki18n( "Science Screen Saver" ), "2.2.0", ki18n( "Science Screen Saver" ) );
     }
 
 
@@ -663,7 +663,7 @@ void KScienceSaver::slotTimeout()
 		myAssert( height() - diam > 0, "assertion violated: height-diam > 0" );
 		y = (double) (height() - diam - 1);
 	}
-	
+
 	xcoord = (int) x ;
 	ycoord = (int) y ;
 	signed int dx = (signed int) xcoord - oldx;
@@ -869,7 +869,7 @@ KScienceSetup::KScienceSetup(  QWidget *parent )
 	showButtonSeparator(true);
 	readSettings();
 	initModeInfo();
-
+       setButtonText( Help, i18n( "A&bout" ) );
 	QWidget *main = new QWidget(this);
 	setMainWidget(main);
 
@@ -1013,6 +1013,7 @@ KScienceSetup::KScienceSetup(  QWidget *parent )
 		palette.setBrush( preview->backgroundRole(), QBrush( p ) );
 	}
 	preview->setPalette( palette );
+	preview->setAutoFillBackground(true);
 	preview->show();	// otherwise saver does not get correct size
 	lt->addWidget( preview );
 
