@@ -76,7 +76,7 @@ public:
 
 int main( int argc, char *argv[] )
 {
-    s_aboutData = new KAboutData( "kslideshow.kss", 0, ki18n("SlideShow"),
+    s_aboutData = new KAboutData( "kslideshow.kss", "klock", ki18n("SlideShow"),
                                   version, ki18n(description), KAboutData::License_GPL,
                                   ki18n("(c) 1999-2003, The KDE Team") );
     s_aboutData->addAuthor(ki18n("Stefan Taferner"), KLocalizedString(), "taferner@kde.org");
@@ -124,9 +124,11 @@ kSlideShowSaver::kSlideShowSaver( WId id ): KScreenSaver(id)
   }
   setAttribute(Qt::WA_NoSystemBackground);
   createNextScreen();
+  show();
 }
 
 
+
 //----------------------------------------------------------------------------
 kSlideShowSaver::~kSlideShowSaver()
 {
@@ -760,11 +762,11 @@ void kSlideShowSaver::createNextScreen()
   mNextScreen.fill(Qt::black);
 
   p.begin(&mNextScreen);
-  
+
   foreach( const mScreenGeo& geo, mGeoList )
   {
     loadNextImage();
-    
+
     iw = mImage.width();
     ih = mImage.height();
     ww = geo.mW;
@@ -944,8 +946,7 @@ kSlideShowSetup::kSlideShowSetup(QWidget *aParent)
 
   QWidget *main = new QWidget(this);
   setMainWidget(main);
-  cfg = new SlideShowCfg();
-  cfg->setupUi( main );
+  cfg = new SlideShowCfg(main);
 
   cfg->mPreview->setFixedSize(220, 170);
   cfg->mPreview->show();    // otherwise saver does not get correct size
@@ -975,6 +976,7 @@ void kSlideShowSetup::readSettings()
     cfg->mCbxZoom->setChecked(config.readEntry("ZoomImages", false));
     cfg->mCbxShowName->setChecked(config.readEntry("PrintName", true));
     cfg->mDelay->setValue(config.readEntry("Delay", 20));
+    cfg->mDelay->setSuffix(ki18np(" second", " seconds"));
     cfg->mDirChooser->setPath(config.readPathEntry("Directory", QString()));
     cfg->mCbxSubdirectory->setChecked(config.readEntry("SubDirectory", false));
     cfg->mCbxRandomPosition->setChecked(config.readEntry("RandomPosition", false));
